@@ -1,5 +1,3 @@
 from athina.datasets.dataset import Dataset
 
-__all__ = [
-    'Dataset'
-]
\ No newline at end of file
+__all__ = ["Dataset"]
