@@ -1,7 +1,19 @@
+import os
 import re
 import json
 import requests
-from typing import Any, Optional
+from typing import Any, Dict, Optional, Tuple, Union
+from athina.evals.grounded.similarity import CosineSimilarity
+from athina.errors.exceptions import NoOpenAiApiKeyException
+from athina.helpers.jinja_helper import PreserveUndefined
+from athina.helpers.json import extract_json_path, validate_json
+from athina.helpers.logger import logger
+from athina.keys.openai_api_key import OpenAiApiKey
+from athina.llms.openai_service import OpenAiService
+from athina.steps.code_execution import CodeExecution
+import subprocess
+import tempfile
+from jinja2 import Environment
 
 
 def _standardize_url(url):
@@ -452,7 +464,7 @@ def equals(expected_text, text, case_sensitive=False, **kwargs):
         expected_text = expected_text.lower()
     if text == expected_text:
         result = True
-        reason = "✅ output exactly matches expected text"
+        reason = "✅ Text exactly matches expected text"
     else:
         result = False
         reason = "output does not exactly match expected text"
@@ -549,6 +561,309 @@ def length_greater_than(min_length, text, **kwargs):
         }
 
 
+def length_between(min_length, max_length, text, **kwargs):
+    """
+    Check if the length of the text is between a specified minimum and maximum length.
+
+    Args:
+        min_length (int): The minimum length that the text should have.
+        max_length (int): The maximum length that the text should have.
+        text (str): The text string to check the length of.
+
+    Returns:
+        dict: A dictionary containing the result of the length check and the reason for the result.
+    """
+    if min_length <= len(text) <= max_length:
+        return {
+            "result": True,
+            "reason": f"output length is between {min_length} and {max_length} characters",
+        }
+    else:
+        return {
+            "result": False,
+            "reason": f"output length is not between {min_length} and {max_length} characters",
+        }
+
+
+def one_line(text, **kwargs):
+    """
+    Check if the text is a single line.
+
+    Args:
+        text (str): The text string to check.
+
+    Returns:
+        dict: A dictionary containing the result of the check and the reason for the result.
+    """
+    if "\n" in text or len(text.splitlines()) > 1:
+        return {"result": False, "reason": "output contains multiple lines"}
+    else:
+        return {"result": True, "reason": "output is a single line"}
+
+
+def json_schema(actual_json: Union[dict, str], **kwargs) -> Dict[str, Any]:
+    """
+    Check if the actual_json matched the schema definition.
+
+    Args:
+        actual_json (dict or str): The JSON string to check with the schema.
+    """
+    try:
+        # Load the actual JSON data from the input
+        actual_json = _load_json(actual_json)
+
+        # Retrieve the schema from the provided keyword arguments
+        schema = _get_schema(kwargs)
+        if not schema:
+            # Return failure if schema is not provided
+            return {"result": False, "reason": "Schema not provided"}
+
+        # Validate the actual JSON against the schema
+        passed, reason = _validate_json_with_schema(actual_json, schema)
+        if not passed:
+            # Return failure if validation does not pass
+            return {"result": False, "reason": reason}
+
+        # Return success if validation passes
+        return {"result": True, "reason": "JSON schema passed"}
+    except Exception as e:
+        # Log and raise any exceptions that occur during the process
+        logger.error(f"Error occurred during JSON schema validation: {e}")
+        raise e
+
+
+def json_validation(
+    actual_json: Union[dict, str], expected_json: Union[dict, str], **kwargs
+) -> Dict[str, Any]:
+    """
+    Check if the actual JSON and expected JSON match the validation rules.
+
+    Args:
+        actual_json (dict or str): The actual JSON string to compare against the expected JSON.
+        expected_json (dict or str): The expected JSON string to compare against the actual JSON.
+    """
+    try:
+        actual_json = _load_json(actual_json)
+        expected_json = _load_json(expected_json)
+
+        validations = kwargs.get("validations", [])
+        if validations:
+            for validation in validations:
+                validation_result = _apply_validation(
+                    actual_json, expected_json, validation
+                )
+                validation_passed = validation_result[0]
+                validation_reason = validation_result[1]
+                if not validation_passed:
+                    return {"result": False, "reason": validation_reason}
+
+        return {"result": True, "reason": "Json validation passed"}
+    except Exception as e:
+        logger.error(f"Error occurred during Json validation eval: {e}")
+        raise e
+
+
+def _bandit_check(code: str) -> None:
+    """
+    Run Bandit security check on the provided code.
+    """
+    with tempfile.NamedTemporaryFile(delete=False, suffix=".py") as temp_file:
+        temp_file.write(code.encode("utf-8"))
+        temp_file_path = temp_file.name
+    try:
+        result = subprocess.run(
+            ["bandit", "-r", temp_file_path, "-f", "json", "-c", "bandit.yml"],
+            capture_output=True,
+            text=True,
+        )
+        if result.returncode != 0:
+            return json.dumps(result.stdout)
+    finally:
+        os.remove(temp_file_path)
+    return None
+
+
+def custom_code_eval(code, **kwargs):
+    """
+    Run custom code provided by the user.
+
+    Args:
+        code (str): The custom code to run.
+
+    Returns:
+        dict: A dictionary containing the result of the check and the reason for the result.
+    """
+    # Create an instance of CodeExecution
+    code_execution = CodeExecution(code=code)
+
+    # Execute the code using the CodeExecution instance
+    result = code_execution.execute(kwargs)
+
+    # Check the result and return the appropriate response
+    if result.get("status") == "success":
+        data = result.get("data")
+        if isinstance(data, bool):
+            if data:
+                return {"result": True, "reason": "Custom eval code passed"}
+            else:
+                return {"result": False, "reason": "Custom eval code failed"}
+        else:
+            return {"result": data, "reason": 'Custom eval code executed'}
+    else:
+        return {
+            "result": False,
+            "reason": result.get("data", "Error in custom eval code eval"),
+        }
+
+
+def _load_json(json_data: Union[dict, str]) -> dict:
+    if isinstance(json_data, str):
+        return json.loads(json_data)
+    return json_data
+
+
+def _get_schema(kwargs: Dict[str, Any]) -> dict:
+    schema = kwargs.get("schema")
+    if schema and isinstance(schema, str):
+        return json.loads(schema.replace("\n", "").replace("\t", ""))
+    return schema
+
+
+def _validate_json_with_schema(json_data: dict, schema: dict) -> Tuple[bool, str]:
+    return validate_json(json_data, schema)
+
+
+def _apply_validation(actual_json: dict, expected_json: dict, validation: dict) -> bool:
+    validating_function = validation.get("validating_function")
+    json_path = validation.get("json_path")
+    actual_value = extract_json_path(actual_json, json_path)
+    expected_value = extract_json_path(expected_json, json_path)
+
+    if validating_function == "Equals":
+        return _validate_equals(actual_value, expected_value, validation, json_path)
+    elif validating_function == "Cosine Similarity":
+        return _validate_cosine_similarity(
+            actual_value, expected_value, validation, json_path
+        )
+    elif validating_function == "LLM Similarity":
+        return _validate_llm_similarity(
+            actual_value, expected_value, validation, json_path
+        )
+    else:
+        error_message = f"Validation function {validating_function} not supported"
+        logger.error(error_message)
+        return False, error_message
+
+
+def _validate_equals(
+    actual_value: Any, expected_value: Any, validation: dict, json_path: str
+) -> bool:
+    case_sensitive = validation.get("case_sensitive", False)
+    if (
+        not case_sensitive
+        and isinstance(actual_value, str)
+        and isinstance(expected_value, str)
+    ):
+        actual_value = str(actual_value).lower()
+        expected_value = str(expected_value).lower()
+    if actual_value != expected_value:
+        error_message = f"JSON path {json_path} does not match expected value"
+        logger.error(error_message)
+        return False, error_message
+    return True, None
+
+
+def _validate_cosine_similarity(
+    actual_value: str, expected_value: str, validation: dict, json_path: str
+) -> bool:
+    threshold = validation.get("pass_threshold", 0.8)
+    cosine_similarity = CosineSimilarity().compare(
+        str(actual_value), str(expected_value)
+    )
+    if cosine_similarity < threshold:
+        error_message = f"Cosine similarity score of {round(cosine_similarity, 2)} for {json_path} is less than the threshold ({threshold})."
+        logger.error(error_message)
+        return False, error_message
+    return True, None
+
+
+def _validate_llm_similarity(
+    actual_value: str, expected_value: str, validation: dict, json_path: str
+) -> bool:
+    open_ai_api_key = (
+        validation.get("open_ai_api_key")
+        or OpenAiApiKey.get_key()
+        or os.environ.get("OPENAI_API_KEY")
+    )
+    if not open_ai_api_key:
+        raise NoOpenAiApiKeyException()
+
+    OpenAiApiKey.set_key(open_ai_api_key)
+    llm_service = OpenAiService()
+    messages = _get_messages(validation, actual_value, expected_value)
+
+    response = llm_service.json_completion(
+        model=validation.get("model", "gpt-3.5-turbo"),
+        messages=messages,
+        temperature=0.0,
+    )
+
+    try:
+        result = response["result"]
+        explanation = response["explanation"]
+        if bool(str(result).lower() == "fail"):
+            error_message = f"LLM Similarity validation failed for {json_path}. Reason: {explanation}"
+            logger.error(error_message)
+            return False, error_message
+        return True, None
+    except Exception as e:
+        error_message = (
+            f"Error occurred during LLM similarity validation for {json_path}"
+        )
+        logger.error(error_message)
+        return False, error_message
+
+
+def _get_messages(validation: dict, actual_value: Any, expected_value: Any) -> list:
+    if validation.get("system_message") and validation.get("user_message"):
+        env = Environment(
+            variable_start_string="{{",
+            variable_end_string="}}",
+            undefined=PreserveUndefined,
+        )
+        render_context = {"actual": actual_value, "expected": expected_value}
+        system_message = env.from_string(validation.get("system_message")).render(
+            render_context
+        )
+        user_message = env.from_string(validation.get("user_message")).render(
+            render_context
+        )
+        return [
+            {"role": "system", "content": system_message},
+            {"role": "user", "content": user_message},
+        ]
+    else:
+        # Default messages
+        system_message = """
+        You are an expert at evaluating whether two given strings are similar or not. Consider semantic similarity also while evaluating.
+        You MUST return a JSON object with the following fields: 
+        - result: Result must be either 'Pass' or 'Fail'.
+        - explanation: An explanation of why the result is Pass or Fail.
+        - score: Any matching score you have used to come to the result.
+        """
+
+        user_message = f"""
+        Following are two strings:
+        1. String 1: {actual_value}.
+        2. String 2: {expected_value}.
+        """
+
+        return [
+            {"role": "system", "content": system_message},
+            {"role": "user", "content": user_message},
+        ]
+
+
 """
 A dictionary containing the available operations and their corresponding functions.
 """
@@ -570,5 +885,10 @@ operations = {
     "EndsWith": ends_with,
     "LengthLessThan": length_less_than,
     "LengthGreaterThan": length_greater_than,
+    "LengthBetween": length_between,
     "ApiCall": api_call,
+    "OneLine": one_line,
+    "JsonSchema": json_schema,
+    "JsonValidation": json_validation,
+    "CustomCodeEval": custom_code_eval,
 }
