@@ -1,5 +1,6 @@
 from jinja2 import Undefined
 
+
 class PreserveUndefined(Undefined):
     def __str__(self):
-        return f'{{ {self._undefined_name} }}'
\ No newline at end of file
+        return f"{{ {self._undefined_name} }}"
