@@ -8,7 +8,11 @@ class LoaderHelper:
     @staticmethod
     def get_loader(eval_name, loader_name: Optional[str] = None):
         """Returns the loader for the given format"""
-        if eval_name == "ContextContainsEnoughInformation" or eval_name == "DoesResponseAnswerQuery" or eval_name == "Faithfulness":
+        if (
+            eval_name == "ContextContainsEnoughInformation"
+            or eval_name == "DoesResponseAnswerQuery"
+            or eval_name == "Faithfulness"
+        ):
             return Loader
         else:
             if loader_name is None:
