@@ -1,5 +1,6 @@
 from abc import ABC, abstractmethod
 
+
 class AbstractLlmService(ABC):
     """
     Abstract class for different Language Learning Model (LLM) Providers.
@@ -8,15 +9,15 @@ class AbstractLlmService(ABC):
     @abstractmethod
     def embeddings(self, text: str) -> list:
         """
-        Fetches embeddings for the given text. This method should be implemented by subclasses 
+        Fetches embeddings for the given text. This method should be implemented by subclasses
         to use the specific LLM provider's embeddings API.
         """
         raise NotImplementedError
 
     @abstractmethod
-    def chat_completion(self, messages, model, **kwargs) -> str:
+    def chat_completion(self, messages, model, **kwargs):
         """
-        Fetches a chat completion response. This method should be implemented by subclasses 
+        Fetches a chat completion response. This method should be implemented by subclasses
         to interact with the specific LLM provider's chat completion API.
         """
         raise NotImplementedError
@@ -24,7 +25,7 @@ class AbstractLlmService(ABC):
     @abstractmethod
     def chat_completion_json(self, messages, model, **kwargs) -> str:
         """
-        Fetches a chat completion response in JSON format. This method should be implemented 
+        Fetches a chat completion response in JSON format. This method should be implemented
         by subclasses to interact with the specific LLM provider's chat completion API using JSON mode.
         """
         raise NotImplementedError
@@ -33,6 +34,14 @@ class AbstractLlmService(ABC):
     def json_completion(self, messages, model, **kwargs):
         """
         Helper method to be implemented by subclasses. This method should call either chat_completion or chat_completion_json.
-        
+
+        """
+        raise NotImplementedError
+    
+    @abstractmethod
+    async def chat_stream_completion(self, messages, model, **kwargs):
+        """
+        Fetches a chat completion response in streaming format. This method should be implemented by subclasses
+        to interact with the specific LLM provider's chat completion API in streaming mode.
         """
         raise NotImplementedError
