@@ -3,6 +3,7 @@ from .text_loader import TextLoader
 from .summary_loader import SummaryLoader
 from .base_loader import BaseLoader, LoadFormat
 from .loader import Loader
+from .json_loader import JsonLoader
 
 __all__ = [
     "ResponseLoader",
@@ -11,4 +12,5 @@ __all__ = [
     "Loader",
     "BaseLoader",
     "LoadFormat",
+    "JsonLoader",
 ]
